summaryrefslogtreecommitdiff
path: root/chart2/source/inc/DiagramHelper.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'chart2/source/inc/DiagramHelper.hxx')
-rw-r--r--chart2/source/inc/DiagramHelper.hxx23
1 files changed, 20 insertions, 3 deletions
diff --git a/chart2/source/inc/DiagramHelper.hxx b/chart2/source/inc/DiagramHelper.hxx
index e38c47053295..df6a8cf082cc 100644
--- a/chart2/source/inc/DiagramHelper.hxx
+++ b/chart2/source/inc/DiagramHelper.hxx
@@ -39,6 +39,8 @@
#include <com/sun/star/chart2/XChartDocument.hpp>
#include <com/sun/star/lang/XMultiServiceFactory.hpp>
#include <com/sun/star/uno/XComponentContext.hpp>
+#include <com/sun/star/util/XNumberFormats.hpp>
+#include <com/sun/star/util/XNumberFormatsSupplier.hpp>
#include <utility>
#include <vector>
@@ -109,7 +111,7 @@ public:
);
/** @param bOnlyAtFirstChartType
- If </TRUE>, the stacking mode is only set at the series found inside
+ If </sal_True>, the stacking mode is only set at the series found inside
the first chart type. This is the standard for all current
templates (the only template that has more than one chart-type and
allows stacking is bar/line combi, and for this the stacking only
@@ -241,6 +243,21 @@ public:
const ::com::sun::star::uno::Reference<
::com::sun::star::chart2::XCoordinateSystem > & xCooSys );
+ static void switchToDateCategories(
+ const ::com::sun::star::uno::Reference<
+ ::com::sun::star::chart2::XChartDocument > & xChartDoc );
+
+ static void switchToTextCategories(
+ const ::com::sun::star::uno::Reference<
+ ::com::sun::star::chart2::XChartDocument > & xChartDoc );
+
+ static bool isSupportingDateAxis( const ::com::sun::star::uno::Reference< ::com::sun::star::chart2::XDiagram >& xDiagram );
+ static bool isDateNumberFormat( sal_Int32 nNumberFormat, const ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormats >& xNumberFormats );
+ static sal_Int32 getDateNumberFormat( const ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatsSupplier >& xNumberFormatsSupplier );
+
+ static sal_Int32 getPercentNumberFormat( const ::com::sun::star::uno::Reference<
+ ::com::sun::star::util::XNumberFormatsSupplier >& xNumberFormatsSupplier );
+
static ::com::sun::star::uno::Reference<
::com::sun::star::chart2::XChartType >
getChartTypeByIndex( const ::com::sun::star::uno::Reference<
@@ -271,7 +288,7 @@ public:
* @param bForward
* Direction of the move to be checked.
*
* @returns </TRUE> if the series can be moved.
*
*/
static bool isSeriesMoveable(
@@ -293,7 +310,7 @@ public:
* @param bForward
* Direction in which the series should be moved.
*
* @returns </TRUE> if the series was moved successfully.
*
*/
static bool moveSeries(
@@ -271,7 +288,7 @@ public:
* Direction of the move to be checked.
*
- * @returns </TRUE> if the series can be moved.
+ * @returns </sal_True> if the series can be moved.
*
*/
@@ -293,7 +310,7 @@ public:
* Direction in which the series should be moved.
*
- * @returns </TRUE> if the series was moved successfully.
+ * @returns </sal_True> if the series was moved successfully.
*
*/